@@ -32,29 +32,10 @@ mod tests {
         assert!(uuid.len() > 0);
     }
 
-    #[test]
-    fn test_uname() {
-        let _ = get_uname().unwrap();
-    }
-
-    #[test]
-    fn test_os_version() {
-        let uname = get_uname().unwrap();
-
-        let os_version = get_os_version().unwrap();
-        let os_version_uname = get_os_version_from_uname(&uname);
-
-        assert_eq!(os_version, os_version_uname);
-    }
-
     #[test]
     fn test_hostname() {
-        let uname = get_uname().unwrap();
-
-        let hostname = get_hostname().unwrap();
-        let hostname_uname = get_hostname_from_uname(&uname);
-
-        assert_eq!(hostname, hostname_uname);
+        // TODO
+        let _hostname = get_hostname().unwrap();
     }
 
     #[test]
